@@ -1,6 +1,3 @@
-# NAME: CAD-OpenSCAD
-# ABSTRACT: Module to generate OpenSCAD files using Perl
-
 use strict; use warnings;
 
 use Object::Pad;
@@ -8,13 +5,13 @@ use CAD::OpenSCAD::Math;
 
 our $Math=new CAD::OpenSCAD::Math;
 
-our $VERSION='0.14';
+our $VERSION='0.15';
 
 =pod
 
 =head1 NAME
 
-CAD::OpenSCAD  
+CAD::OpenSCAD - A module to generate OpenSCAD files for 3D Object creation in Perl
 
 =head2 SYNOPSIS
 
@@ -569,10 +566,17 @@ This just copies the code for the element into new elements, for subsequent tran
   }
 
   
-  method list{ # remove items with certain patterns
+  method list{ # list items with certain patterns
 	   print $_,"\n" foreach (keys %$items);
 	   return $self;
   }
+  
+  method item{
+	  my $sI=shift;
+	  return $items->{$sI} unless(ref $sI);
+	  $items->{$sI->name}=$sI;
+	  return $self;
+  }
     
 
     
@@ -644,7 +648,12 @@ the modules built and the libraries used
 	  $script.=$modules->{$_}  foreach (keys %$modules);
 	  foreach (@_){
 		  if ($items->{$_}){# add items if they exist
-			  $script.=$items->{$_}  ;
+			  if (ref $items->{$_}){
+				 $script.=$items->{$_}->script();			  
+			  }
+			  else{
+				  $script.=$items->{$_}  ;
+			  }
 		  } 
 		  else {
 			  warn "$_ does not exist to build"
@@ -664,6 +673,7 @@ then saves the scad file, and automatically opens OpenSCAD file.
 if another parameter passed, the generates a corresponding file, from one of
 (stl|png|t|off|wrl|amf|3mf|csg|dxf|svg|pdf|png|echo|ast|term|nef3|nefdbg)
 e.g. C<< $scad->save("extrusion","png") >>
+
 =cut
 
   method save{  #
@@ -738,15 +748,85 @@ e.g. C<< $scad->save("extrusion","png") >>
 
 }
 
+=head4 scadItem
+
+This is class for future use to allow an item in OpenSCAD to know its
+dimensions vertexes, faces and orientations.  For now it works with
+polyhedrons to allow distortions.  It is possible that many OpenSCAD
+primitivs will be convertable to scadItem polyhedra to allow such
+manipulations.
+
+=cut
+
 class scadItem{
-   field $name            :reader :param  ;
-   field $description     :reader :writer :param  //="";
-   field $script          :reader :param  //="";
-   field $nDim            :reader         //="3";         # number of dimensions
-   field $insPoint        :reader :writer :param //=[0,0];
-   field $axis            :reader :writer :param //=[1,1,1];
-   field $vertices  = [];
-   field $faces  = [];
+   field $name            :reader :param;               # the name to allow indexing of the item
+   field $description     :reader :writer :param  //="";# optional description
+   field $function        :reader :param ;              # function to generate the scad item
+   field $args            :reader :param ;
+   
+   field $nDim            :reader         //="3";            # number of dimensions
+   field $insPoint        :reader :writer :param //=[0,0];   # translation from original
+   field $axis            :reader :writer :param //=[0,0,0]; # rotation from original
+      
+   method script{
+	   my $buildParams="";
+	   foreach (keys %$args){
+		   $buildParams.="$_=".$Math->serialise($args->{$_}).",\n"
+	   }
+	   substr($buildParams,-2)="";
+	   return "\/\/$name\n$function($buildParams);\n"
+   }
+   
+   method point{
+	   die "No points in Item:$name\n"  && return  unless $args->{points};
+	   my ($index,$newPoint) =@_;
+	   if ($newPoint){
+		   $args->{points}->[$index]=$newPoint;
+		   return;
+	   }
+	   return $args->{points}->[$index]
+   }
+   
+   method scale{
+	   die "No points in Item:$name\n"  && return  unless $args->{points};
+	   my ($index,$dent) =@_;
+	   $index=[$index] unless (ref $index eq "ARRAY");
+	   foreach my $ind (@$index){
+	     for (0..2){
+		   $args->{points}->[$ind]->[$_]*=$dent->[$_]
+	     }
+	   }
+   }
+   
+   method skew{
+	   die "No points in Item:$name\n"  && return  unless $args->{points};
+	   my ($index,$dent) =@_;
+	   $index=[$index] unless (ref $index eq "ARRAY");
+	   foreach my $ind (@$index){
+	     for (0..2){
+		   $args->{points}->[$ind]->[$_]+=$dent->[$_]
+	     }
+	   }
+   } 
+   
+   method adjacent{
+	   my $index=shift;
+	   my $facets=[];my $inds={};
+	   foreach my $face (@{$args->{faces}}){
+		   my $count=0;
+		   foreach my $ptI(@$face){
+			   if ($index==$ptI){
+				   push @$facets,$face;
+				   $inds->{$face->{$count+1}}=$#$facets;
+				   next;
+			   }
+			   $count++;
+		   }
+	   }
+	   
+	   return {facets=>$facets,points=>$inds};
+   }     
+   
 }
 
 =head2 SUPPORT
