@@ -3,10 +3,19 @@ use strict;use warnings;
 use Object::Pad;
 use CAD::OpenSCAD::Math;
 
-our $VERSION='0.14';
+our $VERSION='0.15';
 
 our $Math=new CAD::OpenSCAD::Math;
 
+=pod
+
+=head1 NAME
+
+CAD::OpenSCAD::Loft - A module generate lofted shapes for CAD::OpenSCAD
+
+=cut
+
+
 class CAD::OpenSCAD::Loft{
 	field $scad :param;	
 	
@@ -16,7 +25,7 @@ class CAD::OpenSCAD::Loft{
 		my $faces=[[reverse(0..$#$face1)],@{$self->loftShell($face1,$face2)},[$#$face1+1..$#$face1*2+1]];
 		if ($name){
 			$scad->polyhedron($name,{points=>$pts,faces=>$faces});
-			return $scad
+			return $scad;
 		}
 		return {points=>$pts,faces=>$faces}
 	}
@@ -48,6 +57,7 @@ class CAD::OpenSCAD::Loft{
 		push @$faces,[$#$faces..$#$faces+scalar @$face1];
 		if ($name){
 			$scad->polyhedron($name,{points=>$points,faces=>$faces});
+			return $scad;
 		}
 		return {points=>$points,faces=>$faces}
 	}	
@@ -177,7 +187,11 @@ class CAD::OpenSCAD::Loft{
 	  }
 	  push @$faces,([0,$#$profile+2,1],[reverse(1..$sides+1)]);
 	  $faces=$self->reverseFaces($faces) if $apex->[2]<0;
-	  $scad->polyhedron($name,{points=>$pts,faces=>$faces});
+	  if ($name){
+			$scad->polyhedron($name,{points=>$pts,faces=>$faces});
+			return $scad;
+		}
+		return {points=>$pts,faces=>$faces}
    }
    
    method reverseFaces{
@@ -213,6 +227,7 @@ class CAD::OpenSCAD::Loft{
 		push @$faces,[$#$faces..$#$faces+scalar @$face1];
 		if ($name){
 			$scad->polyhedron($name,{points=>$points,faces=>$faces});
+			return $scad;
 		}
 		return {points=>$points,faces=>$faces}
 	}	
